package gui;
/**
 * Created on 13-08-2002
 *
 * The contents of this file may be used for 
 * private or educational use only.
 */
import java.awt.event.*;
import java.util.*;
import javax.swing.*;
import gui.menu.*;
import util.*;

/**
 * @author Knud Ahrnell Albrechtsen (SnakeByte)
 *
 * To change this generated comment edit the template variable "typecomment":
 * Window>Preferences>Java>Templates.
 * To enable and disable the creation of type comments go to
 * Window>Preferences>Java>Code Generation.
 */
public class MyFrame extends JFrame implements ActionListener, Observer {

private JMenu file, prefs, lookandfeel, lang;
private JMenuItem global, save, exit;
private JCheckBoxMenuItem javalook, windowslook, motiflook;
private JCheckBoxMenuItem dan, eng, ger;
private JMenu help;
private About ab;
private JMenuItem about, hlp;
private LanguageObserver lanobs;
	/**
	 * Constructor MyFrame
	 * @param title
	 */
	public MyFrame( String title ) {
		super( title );
		
		setJMenuBar( makeMenuBar() );
		lanobs = new LanguageObserver();
		lanobs.addObserver( this );
		addWindowListener( new WindowHandler() );
		setResizable( false );
		setSize( 200, 100 );
		setVisible( true );
	}
	
	public void update( Observable obs, Object obj ) {
		Object[] ar = (Object[]) obj;
		//File-menu
		String[] filearr  = (String[]) ar[0];
		file.setText( filearr[0] );
		prefs.setText( filearr[1] );
		save.setText( filearr[2] );
		exit.setText( filearr[3] );
		//prefs-undermenu
		String[] prefsarr = (String[]) ar[1];
		global.setText( prefsarr[0] );
		lookandfeel.setText( prefsarr[1] );
		lang.setText( prefsarr[2] );
		//help-menu
		String[] helparr  = (String[]) ar[2];
		help.setText( helparr[0] );
//		lang.setText( helparr[1] );
		about.setText( helparr[1] );
		hlp.setText( helparr[2] );
		//language-undermenu
		String[] langarr  = (String[]) ar[3];
		dan.setText( langarr[0] );
		eng.setText( langarr[1] );
		ger.setText( langarr[2] );
	}
	
	public JMenuBar makeMenuBar() {
		JMenuBar bar = new JMenuBar();
		
		file = new MySuperJMenu( "File" );
		prefs = new MySuperJMenu( "Preferences" );
		global = new MyJMenuItem( "Global" );
		global.addActionListener( this );
		lookandfeel = new MySuperJMenu( "Look and Feel" );
		javalook = new MyJCheckBoxMenuItem( "Java" );
		javalook.setSelected( true );
		javalook.addActionListener( this );
		windowslook = new MyJCheckBoxMenuItem( "Windows" );
		windowslook.addActionListener( this );
		motiflook = new MyJCheckBoxMenuItem( "Motif" );
		motiflook.addActionListener( this );

		lang = new MySuperJMenu( "Language" );
		dan = new MyJCheckBoxMenuItem( "Danish" );
		dan.addActionListener( this );
		eng = new MyJCheckBoxMenuItem( "English" );
		eng.setSelected( true );
		eng.addActionListener( this );
		ger = new MyJCheckBoxMenuItem( "German" );
		ger.addActionListener( this );
		lang.add( dan );
		lang.add( eng );
		lang.add( ger );

		save = new MyJMenuItem( "Save" );
		save.addActionListener( this );
		exit = new MyJMenuItem( "Exit" );
		exit.addActionListener( this );
		JSeparator sep = new JSeparator();
		
		file.add( prefs );
		file.add( save );
		file.add( sep );
		file.add( exit );
		prefs.add( global );
		prefs.add( lookandfeel );
		prefs.add( lang );
		lookandfeel.add( javalook );
		lookandfeel.add( windowslook );
		lookandfeel.add( motiflook );
		bar.add( file );
		
		help = new MySuperJMenu( "Help" );
		
		about = new MyJMenuItem( "About" );
		about.addActionListener( this );
		hlp = new MyJMenuItem( "Help" );
		hlp.addActionListener( this );
		help.add( about );
		sep = new JSeparator();
		help.add( sep );
		help.add( hlp );
		
		bar.add( help );
		return bar;	
	}
	
	private void lookAndFeel( String s ) {
		try {
			UIManager.setLookAndFeel( s );
			SwingUtilities.updateComponentTreeUI( this );
		}
		catch( UnsupportedLookAndFeelException e ) {
			System.out.println( "UnsupportedLookAndFeelException: " + e );
		}
		catch( IllegalAccessException e ) {
			System.out.println( "IllegalAccessException: " + e );
		}
		catch( InstantiationException e ) {
			System.out.println( "InstantiationException: " + e );
		}
		catch( ClassNotFoundException e ) {
			System.out.println( "ClassNotFoundException: " + e );
		}
	}
	
	public void actionPerformed( ActionEvent e ) {
		Object source = e.getSource();
		if( source == save ) {
			System.out.println( "MyFrame:ActionPerformed: Saving" );
		}
		else if( source == exit ) {
//			System.out.println( "Farvel!" );
			System.exit( 0 );
		}
		else if( source == global ) {
			System.out.println( "MyFrame:ActionPerformed: global" );
		}
		else if( source == javalook ) {
			lookAndFeel( "javax.swing.plaf.metal.MetalLookAndFeel" );
			windowslook.setSelected( false );
			motiflook.setSelected( false );
		}
		else if( source == windowslook ) {
			lookAndFeel( "com.sun.java.swing.plaf.windows.WindowsLookAndFeel" );
			javalook.setSelected( false );
			motiflook.setSelected( false );
		}
		else if( source == motiflook ) {
			lookAndFeel( "com.sun.java.swing.plaf.motif.MotifLookAndFeel" );
			javalook.setSelected( false );
			windowslook.setSelected( false );
		}
		else if( source == dan ) {
			lanobs.setLanguage( "Danish" );
			eng.setSelected( false );
			ger.setSelected( false );
		}
		else if( source == eng ) {
			lanobs.setLanguage( "English" );
			dan.setSelected( false );
			ger.setSelected( false );
		}
		else if( source == ger ) {
			lanobs.setLanguage( "German" );
			dan.setSelected( false );
			eng.setSelected( false );
		}
		else if( source == about ) {
			ab = new About();
		}
		else if( source == hlp ) {
			System.out.println( "MyFrame:ActionPerformed: Help" );
		}
	}
}
